==> express-gateway-plugin-auth2-jwt-1.1.2.tgz: package/request/autenticacao-request.js <==
const odinRequest = require('odin-request-retry');

const autenticaUsuario = (dsLogin, dsSenha, dsHostacesso, urlAutenticacao) => {

    return new Promise((resolve) => {

        let requestTemplate = {
            url: urlAutenticacao,
            method: 'POST',
            resolveWithFullResponse: true,
            json: {
                dsLogin: dsLogin,
                dsSenha: dsSenha,
                dsHostacesso: dsHostacesso
            }
        };

        return resolve(odinRequest.request(requestTemplate, 2));

    });
};

const geraToken = (dsLogin, dsSenha, dsHostacesso, idEmpresa, dsToken, urlGeraToken) => {

    return new Promise((resolve) => {

        let requestTemplate = {
            url: urlGeraToken,
            method: 'POST',
            resolveWithFullResponse: true,
            json: {
                dsLogin: dsLogin,
                dsSenha: dsSenha,
                dsHostacesso: dsHostacesso,
                idEmpresa: idEmpresa,
                dsToken: dsToken
            }
        };

        return resolve(odinRequest.request(requestTemplate, 2));

    });
};

const validaToken = (token, urlAutorizacao) => {

    return new Promise((resolve) => {

        let requestTemplate = {
            url: urlAutorizacao,
            method: "POST",
            resolveWithFullResponse: true,
            json: {
                "dsToken": token
            }
        };

        return resolve(odinRequest.request(requestTemplate, 2));

    });

}

module.exports = {
    autenticaUsuario,
    geraToken,
    validaToken
}

==> express-gateway-plugin-auth2-jwt-3.0.0.tgz: package/request/autenticacao-request.js <==
const odinRequest = require('odin-request-retry');

const autenticaUsuario = (dsLogin, dsSenha, dsHostacesso, urlAutenticacao) => {

    return new Promise((resolve) => {

        let requestTemplate = {
            url: urlAutenticacao,
            method: 'POST',
            resolveWithFullResponse: true,
            json: {
                dsLogin: dsLogin,
                dsSenha: dsSenha,
                dsHostacesso: dsHostacesso
            }
        };

        return resolve(odinRequest.request(requestTemplate, 2));

    });
};

const geraToken = (dsLogin, dsSenha, dsHostacesso, idEmpresa, info, dsToken, urlGeraToken) => {

    return new Promise((resolve) => {

        let requestTemplate = {
            url: urlGeraToken,
            method: 'POST',
            resolveWithFullResponse: true,
            json: {
                dsLogin: dsLogin,
                dsSenha: dsSenha,
                dsHostacesso: dsHostacesso,
                info: info,
                idEmpresa: idEmpresa,
                dsToken: dsToken
            }
        };

        return resolve(odinRequest.request(requestTemplate, 2));

    });
};

const validaToken = (token, urlAutorizacao) => {

    return new Promise((resolve) => {

        let requestTemplate = {
            url: urlAutorizacao,
            method: "POST",
            resolveWithFullResponse: true,
            json: {
                "dsToken": token
            }
        };

        return resolve(odinRequest.request(requestTemplate, 2));

    });

}

module.exports = {
    autenticaUsuario,
    geraToken,
    validaToken
}
